==> kolourpaint-17.08.0.tar.xz: kolourpaint-17.08.0/commands/imagelib/effects/kpEffectBlurSharpenCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectBlurSharpenCommand_H
#define kpEffectBlurSharpenCommand_H


#include "kpEffectCommandBase.h"
#include "imagelib/effects/kpEffectBlurSharpen.h"
#include "imagelib/kpImage.h"


class kpEffectBlurSharpenCommand : public kpEffectCommandBase
{
public:
    kpEffectBlurSharpenCommand (kpEffectBlurSharpen::Type type,
                                int strength,
                                bool actOnSelection,
                                kpCommandEnvironment *environ);
    virtual ~kpEffectBlurSharpenCommand ();

    static QString nameForType (kpEffectBlurSharpen::Type type);

protected:
    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;

protected:
    kpEffectBlurSharpen::Type m_type;
    int m_strength;
};


#endif  // kpEffectBlurSharpenCommand_H

==> kolourpaint-18.08.1.tar.xz: kolourpaint-18.08.1/commands/imagelib/effects/kpEffectBlurSharpenCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectBlurSharpenCommand_H
#define kpEffectBlurSharpenCommand_H


#include "kpEffectCommandBase.h"
#include "imagelib/effects/kpEffectBlurSharpen.h"
#include "imagelib/kpImage.h"


class kpEffectBlurSharpenCommand : public kpEffectCommandBase
{
public:
    kpEffectBlurSharpenCommand (kpEffectBlurSharpen::Type type,
                                int strength,
                                bool actOnSelection,
                                kpCommandEnvironment *environ);
    ~kpEffectBlurSharpenCommand () override;

    static QString nameForType (kpEffectBlurSharpen::Type type);

protected:
    kpImage applyEffect (const kpImage &image) override;

protected:
    kpEffectBlurSharpen::Type m_type;
    int m_strength;
};


#endif  // kpEffectBlurSharpenCommand_H
